#!/bin/bash
################################# usbpix.sh #######################################
###             								###
###    Using the usb-storage module, you can mount a digital camera     	###
###    and retrive the images to a subdirectory on your harddrive.		###
###    This script has only been tested with the Finepix 4700			###
###    										###
###		Copyright (C) 2001 Haakon Meland Eriksen	        	###
###										###
### This program is free software; you can redistribute it and/or modify	###
### it under the terms of the GNU General Public License as published by	###
### the Free Software Foundation; either version 2 of the License, or		###
### (at your option) any later version.						###
###										###
### This program is distributed in the hope that it will be useful,		###
### but WITHOUT ANY WARRANTY; without even the implied warranty of		###
### MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the		###
### GNU General Public License for more details.				###
###										###
### You should have received a copy of the GNU General Public License		###
### along with this program; if not, write to the Free Software			###
### Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	###  
### USA										###
###										###
###### Contact information: Haakon Meland Eriksen, haakon@nhn.no ##################


############################## CONFIGURATION ############################
## ADD the following line to /etc/fstab. This is tested on SuSE Linux 7.2
## /dev/sda1       /mnt/usb/finepix4700 auto       noauto,user 0 0
## 
## CHANGE the permissions like this: chmod 0754
## This will allow the owner read, write and execute permissions, the
## group will get read and execute permissions, and everyone else will get
## read permissions

MOUNTPOINT=/mnt/usb/finepix4700
CAMERA_SUBDIRECTORY=dcim/100_fuji
#echo $MOUNTPOINT/$CAMERA_SUBDIRECTORY
#########################################################################

#############  Mount camera ###################
echo -e "\v"
echo "********* Trying to mount the camera... ********"
echo -en "\t"
echo "-> Checking if the camera is already mounted."

SUCCESS=0
mount | grep -q $MOUNTPOINT

if [ ! $? -eq $SUCCESS ]
	then
		echo -en "\t"
		echo "-> The camera is not mounted. Mounting the camera..."
		mount $MOUNTPOINT
	else
		echo -en "\t"
		echo "-> The camera is already mounted. I will remount the camera..."
		umount $MOUNTPOINT
		mount $MOUNTPOINT
fi

if [ ! $? -eq $SUCCESS ]
	then
		echo "******** Unable to mount the camera! Is the camera connected? ********"
		echo -e "\v"		
		exit 0
fi


############### Create subdirectory for images ################
#Get the date. Use date as directory name. Rerunning the script within a minute will fail, 
#because the subdirectory already exists.

#PREFIX=
SUFFIX=`eval date +%Y%m%d%H%M`

#DIRCTORYNAME=$PREFIX.$SUFFIX
DIRECTORYNAME=$SUFFIX

#Create a new subdirectory for the new images
WORKING_DIRECTORY=$PWD


echo -e "\v"
echo "******** Trying to create a new subdirectory... ********"
echo "-> Checking if directory exists already..."
if [ ! -d "$WORKING_DIRECTORY/$DIRECTORYNAME" ]
	then
		echo -en "\t"
		echo "-> Creating a new subdirectory of:" $WORKING_DIRECTORY
		echo -en "\t"
		echo "-> Name of the new subdirectory:" $DIRECTORYNAME
		mkdir $WORKING_DIRECTORY/$DIRECTORYNAME
	else
		echo -en "\t"
		echo "->" $DIRECTORYNAME "exists already"
		exit 0
fi

if [ ! $? -eq $SUCCESS ]
	then
		echo -en "\t"
		echo "******** Unable to create the subdirectory. Exiting... ********"
		echo -e "\v"
		exit 0
fi

################## Copy the images from the camera to the new directory ######################
echo -e "\v"
echo "******* Trying to copy files from the camera... *******"
echo -en "\t"
echo "-> Copying files from the camera to the new subdirectory..."
cp -v $MOUNTPOINT/$CAMERA_SUBDIRECTORY/* $WORKING_DIRECTORY/$DIRECTORYNAME

if [ ! $? -eq $SUCCESS ]
	then
		echo "******** Unable to copy files from the camera to the new subdirectory. Exiting... ********"
		echo -e "\v"
		exit 0
fi

##################### Unmounting the camera ####################################
echo -e "\v"
echo "******** Trying to umount the camera... ********"
echo -en "\t"
echo "-> Unmounting the camera..."
umount $MOUNTPOINT

if [ ! $? -eq $SUCCESS ]
	then
		echo "******** Unable to unmount the camera. Exiting... ********"
		echo "\v"
		exit 0
fi
